is_overflow_witness

Function is_overflow_witness 

pub fn is_overflow_witness(
    tasks: &[Interval],
    machines: usize,
    witness: &[usize],
) -> bool
Re-check an overflow witness: all the listed tasks pairwise overlap and there are more than machines of them — a clique that cannot be coloured with machines colours.