pub fn is_overflow_witness(
tasks: &[Interval],
machines: usize,
witness: &[usize],
) -> boolExpand description
Re-check an overflow witness: all the listed tasks pairwise overlap and there are more than
machines of them — a clique that cannot be coloured with machines colours.